/* eslint-env node */
const path = require('path');
const webpack = require('webpack');
const { DefinePlugin, ProvidePlugin } = webpack;
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const UglifyJSPlugin = require('uglifyjs-webpack-plugin');
const CleanWebpackPlugin = require('clean-webpack-plugin');
const ModernizrWebpackPlugin = require('modernizr-webpack-plugin');

const isProduction = process.env.NODE_ENV === 'production';

const extractSass = new ExtractTextPlugin({
  filename: 'css/[name].css',
});

const config = {
  entry: './js/script.js',
  output: {
    filename: 'js/[name].js',
    path: path.resolve(__dirname, 'dist')
  },
  devtool: isProduction ? 'source-map' : 'cheap-module-eval-source-map',
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /node_modules/,
        loader: 'babel-loader',
      },
      {
        test: /\.scss$|\.css$/,
        use: extractSass.extract({
          use: [
            {
              loader: 'css-loader',
              options: {
                minimize: isProduction,
                sourceMap: !isProduction
              },
            },
            {
              loader: 'resolve-url-loader',
              options: {
                sourceMap: !isProduction,
                root: '../'
              }
            },
            {
              loader: 'sass-loader',
              options: {
                sourceMap: true
              }
            },
          ],
          fallback: 'style-loader' + (!isProduction ? '?sourceMap' : '')
        }),
      },
      {
        test: /\.(png|jpg|gif|svg|eot|woff2|woff|ttf)$/,
        use: [
          {
            loader: 'file-loader',
            options: {
              outputPath: 'assets/',
              publicPath: '../'
            },
          },
        ],
      }
    ],
  },
  plugins: [
    extractSass,
    new CleanWebpackPlugin(['./dist']),
    new ProvidePlugin({
      'jQuery': 'jquery'
    }),
    // Build our own Modernizer so we can remove the .details class on the
    // <html> element.
    new ModernizrWebpackPlugin({
      filename: 'js/modernizer.js',
      minify: isProduction,
      classPrefix: "modernizr-",
      options: [
        "addTest",
        "prefixes",
        "testStyles"
      ],
      "feature-detects": [
        "elem/details",
        "inputtypes",
        "touchevents"
      ]
    }),
  ],
};

if (isProduction) {
  config.plugins.push(new UglifyJSPlugin({
    sourceMap: true,
  }));
}

module.exports = config;
